@@ -1,5 +1,5 @@
 __productname__ = "nusex"
-__version__ = "0.2.0"
+__version__ = "0.4.0"
 __description__ = "A project templating utility for Python."
 __url__ = "https://github.com/parafoxia/nusex"
 __docs__ = "https://nusex.readthedocs.io/en/latest/"
@@ -13,7 +13,9 @@ from pathlib import Path
 
 if os.name == "nt":
     CONFIG_DIR = Path.home() / ".nusex"
+    TEMP_DIR = CONFIG_DIR / "tmp"
 else:
     CONFIG_DIR = Path.home() / ".config/nusex"
+    TEMP_DIR = Path("/tmp/nusex")
 
 from . import commands
